unit Unit2;

interface

uses
  System.Messaging, FMX.Platform,
  /////
  System.SysUtils, System.Types, System.UITypes, System.Classes, System.Variants,
  FMX.Types, FMX.Controls, FMX.Forms, FMX.Graphics, FMX.Dialogs, FMX.Objects,
  FMX.Layouts;

type
  TForm2 = class(TForm)
    Layout1: TLayout;
    Text1: TText;
    Text2: TText;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    { Private declarations }
    ScreenOrientation: TScreenOrientation;
    OrientationChangedId: Integer;

    function GetScreenOrientationStr(AScreenOrientation: TScreenOrientation): string;

    procedure OrientationChanged(const Sender: TObject; const Msg: TMessage);
    function GetScreenOrientation: TScreenOrientation;
  public
    { Public declarations }
  end;

var
  Form2: TForm2;

implementation

{$R *.fmx}

{ TForm2 }

procedure TForm2.FormCreate(Sender: TObject);
begin
  ScreenOrientation := GetScreenOrientation;
  Text1.Text := GetScreenOrientationStr(ScreenOrientation);

  OrientationChangedId := TMessageManager.DefaultManager.SubscribeToMessage
    (TOrientationChangedMessage, OrientationChanged);
end;

procedure TForm2.FormDestroy(Sender: TObject);
begin
  TMessageManager.DefaultManager.Unsubscribe(TOrientationChangedMessage,
    OrientationChangedId);
end;

function TForm2.GetScreenOrientation: TScreenOrientation;
begin
  Result := IFMXScreenService(TPlatformServices.Current.GetPlatformService
    (IFMXScreenService)).GetScreenOrientation;
end;

function TForm2.GetScreenOrientationStr(
  AScreenOrientation: TScreenOrientation): string;
begin
  Result := 'Unknown';
  case AScreenOrientation of
    TScreenOrientation.Portrait: Result := 'Portrait';
    TScreenOrientation.Landscape: Result := 'Landscape';
    TScreenOrientation.InvertedPortrait: Result := 'InvertedPortrait';
    TScreenOrientation.InvertedLandscape: Result := 'InvertedLandscape';
  end;
end;

procedure TForm2.OrientationChanged(const Sender: TObject; const Msg: TMessage);
var
  NewScreenOrientation: TScreenOrientation;
begin
  NewScreenOrientation := GetScreenOrientation;

  Text1.Text := GetScreenOrientationStr(ScreenOrientation);
  Text2.Text := GetScreenOrientationStr(NewScreenOrientation);

  ScreenOrientation := NewScreenOrientation;

end;

end.
